aboutsummaryrefslogtreecommitdiff
path: root/gold/output.h
diff options
context:
space:
mode:
authorIan Lance Taylor <ian@airs.com>2009-02-28 00:12:26 +0000
committerIan Lance Taylor <ian@airs.com>2009-02-28 00:12:26 +0000
commite29e076ab80ed58ab0343c9910e02df7220233f8 (patch)
tree20a8d5b7d3ae61e0551d66d89799f6ff7d209f8d /gold/output.h
parenta5a437df7713387228e9ba87aa1e20b33ae20fb1 (diff)
downloadgdb-e29e076ab80ed58ab0343c9910e02df7220233f8.zip
gdb-e29e076ab80ed58ab0343c9910e02df7220233f8.tar.gz
gdb-e29e076ab80ed58ab0343c9910e02df7220233f8.tar.bz2
PR 7091
* output.cc (Output_section::find_starting_output_address): Rename from starting_output_address; add PADDR parameter; change return type. * output.h (class Output_section): Declare find_starting_output_address instead of starting_output_address. * object.cc (Sized_relobj::do_finalize_local_symbols): Handle a section symbol for which we can't find a merge section.
Diffstat (limited to 'gold/output.h')
-rw-r--r--gold/output.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/gold/output.h b/gold/output.h
index 9f075be..6c37dfd 100644
--- a/gold/output.h
+++ b/gold/output.h
@@ -1,6 +1,6 @@
// output.h -- manage the output file for gold -*- C++ -*-
-// Copyright 2006, 2007, 2008 Free Software Foundation, Inc.
+// Copyright 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
// Written by Ian Lance Taylor <iant@google.com>.
// This file is part of gold.
@@ -2260,12 +2260,14 @@ class Output_section : public Output_data
output_address(const Relobj* object, unsigned int shndx,
off_t offset) const;
- // Return the output address of the start of the merged section for
- // input section SHNDX in object OBJECT. This is not necessarily
- // the offset corresponding to input offset 0 in the section, since
- // the section may be mapped arbitrarily.
- uint64_t
- starting_output_address(const Relobj* object, unsigned int shndx) const;
+ // Look for the merged section for input section SHNDX in object
+ // OBJECT. If found, return true, and set *ADDR to the address of
+ // the start of the merged section. This is not necessary the
+ // output offset corresponding to input offset 0 in the section,
+ // since the section may be mapped arbitrarily.
+ bool
+ find_starting_output_address(const Relobj* object, unsigned int shndx,
+ uint64_t* addr) const;
// Record that this output section was found in the SECTIONS clause
// of a linker script.